==> qt5-base-debuginfo-5.4.2-2.tar.xz: usr/src/debug/qt5-base-5.4.2-2/examples/widgets/itemviews/customsortfiltermodel/.rcc/qrc_customsortfiltermodel.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.4.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.4.2-2.i686/src/qtbase-opensource-src-5.4.2/examples/widgets/itemviews/customsortfiltermodel/images/find.png
  0x0,0x0,0x2,0xe1,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x4,0x67,0x41,0x4d,0x41,0x0,0x0,0xd6,0xd8,0xd4,0x4f,0x58,0x32,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x41,0x64,0x6f,0x62,0x65,0x20,0x49,0x6d,0x61,0x67,0x65,0x52,0x65,0x61,0x64,
  0x79,0x71,0xc9,0x65,0x3c,0x0,0x0,0x2,0x73,0x49,0x44,0x41,0x54,0x78,0xda,0x8c,
  0x53,0x4b,0x68,0x13,0x51,0x14,0xbd,0x6f,0x32,0x2f,0xbf,0x12,0x93,0x34,0x29,0x89,
  0xa5,0x8d,0xd2,0x58,0x6b,0xd4,0x8a,0x18,0x6a,0x57,0x22,0x6e,0x84,0x2a,0x48,0x17,
  0x82,0xab,0x4a,0x37,0x22,0x22,0xb8,0xe8,0xce,0x85,0x54,0xc1,0x85,0x3b,0x71,0x2d,
  0x75,0xa7,0x82,0x58,0x3f,0x88,0xe8,0xae,0x2a,0x8,0x69,0x55,0xb4,0x9f,0x11,0x4c,
  0x53,0x6d,0x6b,0xda,0x7c,0xb0,0x3f,0xd3,0x4c,0x32,0xc9,0x24,0xe3,0xbd,0x33,0x13,
  0x35,0xa1,0x82,0xf,0xe,0xef,0xcd,0xbb,0xef,0x9c,0x7b,0xde,0xbd,0x6f,0x98,0xa6,
  0x69,0xb0,0xd5,0x60,0x8c,0x9,0x38,0xd5,0xc0,0xcc,0x6d,0x3a,0x5c,0x25,0x20,0x8f,
  0x66,0x10,0xb7,0x24,0xb7,0x45,0x45,0x38,0x37,0x36,0x0,0xcc,0xd2,0xf,0x16,0xde,
  0xab,0xb,0x94,0xb,0xef,0x41,0x5e,0x79,0x1,0xf,0x7,0xef,0x41,0x29,0x2f,0x63,
  0x82,0x32,0x8a,0x54,0x58,0xa3,0x3,0x9d,0x7c,0xf2,0xe6,0x35,0x7b,0xb3,0xeb,0x54,
  0x64,0xa7,0x27,0x77,0xb0,0xdd,0xb9,0x83,0xf6,0x3f,0x7c,0xcd,0x25,0xbf,0x2c,0xae,
  0xb9,0x95,0xa5,0xf9,0x31,0x78,0x30,0x70,0x1d,0x54,0x65,0x1d,0xb9,0xf9,0x3a,0x1,
  0x54,0x65,0x98,0x79,0xd0,0xee,0xf7,0xc,0xf5,0xf7,0x6e,0xe7,0x7b,0x2,0xbc,0x8b,
  0xb,0x86,0xfb,0x72,0x55,0x3,0x29,0x59,0x8a,0x3f,0x8d,0x2d,0xb0,0x52,0x7c,0xe2,
  0x2e,0x3c,0xbb,0x74,0x1b,0xb9,0xcb,0x42,0x83,0x7b,0xb,0xd9,0x3e,0xb0,0xcb,0x93,
  0x3b,0xd4,0x6e,0xeb,0xf2,0x37,0x89,0xd0,0xe2,0x32,0x40,0xeb,0x9e,0xe,0xfb,0xee,
  0x48,0xa8,0x79,0x3,0xdc,0x6d,0xc7,0xf1,0xac,0x7f,0xab,0x1a,0x8,0x74,0xe7,0x23,
  0xe1,0x6d,0x15,0x8f,0xc3,0x2,0x2e,0x9b,0x0,0x76,0x6e,0xe4,0x28,0x96,0xab,0x60,
  0x55,0x18,0x1c,0xdb,0xef,0x6b,0x9d,0x94,0x7c,0x4e,0xdc,0x72,0xd7,0x9,0xe8,0xf6,
  0x8d,0x6a,0x33,0x87,0x55,0xd0,0xc9,0x6e,0x14,0x71,0x5a,0xd,0x1,0xb9,0x64,0x5c,
  0x85,0x62,0xa0,0x69,0xf4,0x61,0x7,0xb3,0x45,0xf5,0x3,0xab,0xfd,0x66,0xee,0x67,
  0xd2,0xc9,0xb3,0x3a,0xd9,0xc1,0xd,0xd0,0x9a,0xdc,0xbc,0xfa,0xbc,0x9a,0x86,0xcd,
  0x4c,0xe2,0x8f,0xe5,0x5a,0x83,0x8d,0x6a,0x6a,0xd4,0x2a,0x29,0xbe,0x14,0x54,0x57,
  0x6f,0xa9,0x2,0xa4,0xea,0xb4,0x63,0xf3,0xa5,0xd9,0x8f,0x89,0xac,0x17,0x52,0x93,
  0xef,0xe8,0x56,0xba,0xf3,0xbf,0xbb,0x70,0xa5,0xcf,0x31,0x5b,0x1,0xa6,0x7c,0xea,
  0x3c,0xdf,0x31,0xee,0x3e,0xbd,0x12,0xdd,0x17,0x4a,0x9f,0x89,0xb6,0xb4,0x52,0xec,
  0xfe,0x78,0x36,0xfd,0x76,0x26,0xe5,0x2d,0x4a,0xb1,0x19,0x78,0x3e,0x34,0x2,0x5a,
  0xf5,0x1b,0x72,0xa7,0x7e,0xb,0xc,0x9f,0x70,0xc4,0x45,0x11,0x3a,0xe5,0x82,0x6,
  0x59,0x19,0x16,0xee,0x38,0x2f,0x3f,0x81,0x40,0xf7,0x61,0x68,0xf2,0x47,0xf4,0x3b,
  0x93,0x6d,0xca,0xfc,0xfa,0xc6,0x4b,0x24,0x93,0xb5,0x24,0xb5,0x51,0x2f,0xe2,0x70,
  0x9f,0x23,0xc1,0x39,0x84,0x83,0x41,0xe,0xa9,0x74,0x19,0x8a,0x6b,0x15,0xaf,0x6d,
  0xe2,0xaa,0xa4,0xa8,0xf0,0xc8,0x7c,0xbe,0x76,0xd3,0x24,0xd9,0xde,0x40,0xfc,0x30,
  0x67,0x10,0x89,0x6c,0xb5,0x42,0x38,0x10,0xe0,0x90,0xc9,0x94,0x41,0xfa,0xae,0xe6,
  0x47,0xa7,0xd5,0x51,0xb5,0x2,0x79,0x8c,0x53,0xa6,0x4d,0x4,0xaf,0x95,0xd8,0x14,
  0x29,0x98,0x6b,0x10,0x5,0x11,0xb2,0x8a,0xa2,0x85,0x89,0x3c,0xbd,0xa8,0xca,0x48,
  0x7e,0x8c,0x64,0x2a,0xd2,0x14,0x62,0xd9,0x3c,0xf8,0xcf,0x9f,0x89,0x86,0xef,0xe2,
  0x51,0x9b,0x74,0xb6,0x87,0xaf,0x8b,0x16,0x18,0xc1,0xef,0xb,0x88,0xbd,0x8,0x1b,
  0xd5,0xc7,0xac,0x11,0xab,0x15,0xbc,0x11,0x14,0xb0,0x22,0x42,0x88,0x6e,0xf3,0x61,
  0x49,0x88,0x39,0xc,0x2a,0xf0,0x1f,0xe3,0x97,0x0,0x3,0x0,0xfd,0x37,0x1f,0x33,
  0x80,0xf7,0xa0,0x10,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
  
};

static const unsigned char qt_resource_name[] = {
  // images
  0x0,0x6,
  0x7,0x3,0x7d,0xc3,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x73,
    // find.png
  0x0,0x8,
  0x0,0x47,0x5a,0xe7,
  0x0,0x66,
  0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/images
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/images/find.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_customsortfiltermodel)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_customsortfiltermodel)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_customsortfiltermodel)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_customsortfiltermodel)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_customsortfiltermodel)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_customsortfiltermodel)(); }
   } dummy;
}

==> qt5-base-debuginfo-5.5.1-1.tar.xz: usr/src/debug/qt5-base-5.5.1-1/examples/widgets/itemviews/customsortfiltermodel/.rcc/qrc_customsortfiltermodel.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.5.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.5.1-1.x86_64/src/qtbase-opensource-src-5.5.1/examples/widgets/itemviews/customsortfiltermodel/images/find.png
  0x0,0x0,0x2,0xe1,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x4,0x67,0x41,0x4d,0x41,0x0,0x0,0xd6,0xd8,0xd4,0x4f,0x58,0x32,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x41,0x64,0x6f,0x62,0x65,0x20,0x49,0x6d,0x61,0x67,0x65,0x52,0x65,0x61,0x64,
  0x79,0x71,0xc9,0x65,0x3c,0x0,0x0,0x2,0x73,0x49,0x44,0x41,0x54,0x78,0xda,0x8c,
  0x53,0x4b,0x68,0x13,0x51,0x14,0xbd,0x6f,0x32,0x2f,0xbf,0x12,0x93,0x34,0x29,0x89,
  0xa5,0x8d,0xd2,0x58,0x6b,0xd4,0x8a,0x18,0x6a,0x57,0x22,0x6e,0x84,0x2a,0x48,0x17,
  0x82,0xab,0x4a,0x37,0x22,0x22,0xb8,0xe8,0xce,0x85,0x54,0xc1,0x85,0x3b,0x71,0x2d,
  0x75,0xa7,0x82,0x58,0x3f,0x88,0xe8,0xae,0x2a,0x8,0x69,0x55,0xb4,0x9f,0x11,0x4c,
  0x53,0x6d,0x6b,0xda,0x7c,0xb0,0x3f,0xd3,0x4c,0x32,0xc9,0x24,0xe3,0xbd,0x33,0x13,
  0x35,0xa1,0x82,0xf,0xe,0xef,0xcd,0xbb,0xef,0x9c,0x7b,0xde,0xbd,0x6f,0x98,0xa6,
  0x69,0xb0,0xd5,0x60,0x8c,0x9,0x38,0xd5,0xc0,0xcc,0x6d,0x3a,0x5c,0x25,0x20,0x8f,
  0x66,0x10,0xb7,0x24,0xb7,0x45,0x45,0x38,0x37,0x36,0x0,0xcc,0xd2,0xf,0x16,0xde,
  0xab,0xb,0x94,0xb,0xef,0x41,0x5e,0x79,0x1,0xf,0x7,0xef,0x41,0x29,0x2f,0x63,
  0x82,0x32,0x8a,0x54,0x58,0xa3,0x3,0x9d,0x7c,0xf2,0xe6,0x35,0x7b,0xb3,0xeb,0x54,
  0x64,0xa7,0x27,0x77,0xb0,0xdd,0xb9,0x83,0xf6,0x3f,0x7c,0xcd,0x25,0xbf,0x2c,0xae,
  0xb9,0x95,0xa5,0xf9,0x31,0x78,0x30,0x70,0x1d,0x54,0x65,0x1d,0xb9,0xf9,0x3a,0x1,
  0x54,0x65,0x98,0x79,0xd0,0xee,0xf7,0xc,0xf5,0xf7,0x6e,0xe7,0x7b,0x2,0xbc,0x8b,
  0xb,0x86,0xfb,0x72,0x55,0x3,0x29,0x59,0x8a,0x3f,0x8d,0x2d,0xb0,0x52,0x7c,0xe2,
  0x2e,0x3c,0xbb,0x74,0x1b,0xb9,0xcb,0x42,0x83,0x7b,0xb,0xd9,0x3e,0xb0,0xcb,0x93,
  0x3b,0xd4,0x6e,0xeb,0xf2,0x37,0x89,0xd0,0xe2,0x32,0x40,0xeb,0x9e,0xe,0xfb,0xee,
  0x48,0xa8,0x79,0x3,0xdc,0x6d,0xc7,0xf1,0xac,0x7f,0xab,0x1a,0x8,0x74,0xe7,0x23,
  0xe1,0x6d,0x15,0x8f,0xc3,0x2,0x2e,0x9b,0x0,0x76,0x6e,0xe4,0x28,0x96,0xab,0x60,
  0x55,0x18,0x1c,0xdb,0xef,0x6b,0x9d,0x94,0x7c,0x4e,0xdc,0x72,0xd7,0x9,0xe8,0xf6,
  0x8d,0x6a,0x33,0x87,0x55,0xd0,0xc9,0x6e,0x14,0x71,0x5a,0xd,0x1,0xb9,0x64,0x5c,
  0x85,0x62,0xa0,0x69,0xf4,0x61,0x7,0xb3,0x45,0xf5,0x3,0xab,0xfd,0x66,0xee,0x67,
  0xd2,0xc9,0xb3,0x3a,0xd9,0xc1,0xd,0xd0,0x9a,0xdc,0xbc,0xfa,0xbc,0x9a,0x86,0xcd,
  0x4c,0xe2,0x8f,0xe5,0x5a,0x83,0x8d,0x6a,0x6a,0xd4,0x2a,0x29,0xbe,0x14,0x54,0x57,
  0x6f,0xa9,0x2,0xa4,0xea,0xb4,0x63,0xf3,0xa5,0xd9,0x8f,0x89,0xac,0x17,0x52,0x93,
  0xef,0xe8,0x56,0xba,0xf3,0xbf,0xbb,0x70,0xa5,0xcf,0x31,0x5b,0x1,0xa6,0x7c,0xea,
  0x3c,0xdf,0x31,0xee,0x3e,0xbd,0x12,0xdd,0x17,0x4a,0x9f,0x89,0xb6,0xb4,0x52,0xec,
  0xfe,0x78,0x36,0xfd,0x76,0x26,0xe5,0x2d,0x4a,0xb1,0x19,0x78,0x3e,0x34,0x2,0x5a,
  0xf5,0x1b,0x72,0xa7,0x7e,0xb,0xc,0x9f,0x70,0xc4,0x45,0x11,0x3a,0xe5,0x82,0x6,
  0x59,0x19,0x16,0xee,0x38,0x2f,0x3f,0x81,0x40,0xf7,0x61,0x68,0xf2,0x47,0xf4,0x3b,
  0x93,0x6d,0xca,0xfc,0xfa,0xc6,0x4b,0x24,0x93,0xb5,0x24,0xb5,0x51,0x2f,0xe2,0x70,
  0x9f,0x23,0xc1,0x39,0x84,0x83,0x41,0xe,0xa9,0x74,0x19,0x8a,0x6b,0x15,0xaf,0x6d,
  0xe2,0xaa,0xa4,0xa8,0xf0,0xc8,0x7c,0xbe,0x76,0xd3,0x24,0xd9,0xde,0x40,0xfc,0x30,
  0x67,0x10,0x89,0x6c,0xb5,0x42,0x38,0x10,0xe0,0x90,0xc9,0x94,0x41,0xfa,0xae,0xe6,
  0x47,0xa7,0xd5,0x51,0xb5,0x2,0x79,0x8c,0x53,0xa6,0x4d,0x4,0xaf,0x95,0xd8,0x14,
  0x29,0x98,0x6b,0x10,0x5,0x11,0xb2,0x8a,0xa2,0x85,0x89,0x3c,0xbd,0xa8,0xca,0x48,
  0x7e,0x8c,0x64,0x2a,0xd2,0x14,0x62,0xd9,0x3c,0xf8,0xcf,0x9f,0x89,0x86,0xef,0xe2,
  0x51,0x9b,0x74,0xb6,0x87,0xaf,0x8b,0x16,0x18,0xc1,0xef,0xb,0x88,0xbd,0x8,0x1b,
  0xd5,0xc7,0xac,0x11,0xab,0x15,0xbc,0x11,0x14,0xb0,0x22,0x42,0x88,0x6e,0xf3,0x61,
  0x49,0x88,0x39,0xc,0x2a,0xf0,0x1f,0xe3,0x97,0x0,0x3,0x0,0xfd,0x37,0x1f,0x33,
  0x80,0xf7,0xa0,0x10,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
  
};

static const unsigned char qt_resource_name[] = {
  // images
  0x0,0x6,
  0x7,0x3,0x7d,0xc3,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x73,
    // find.png
  0x0,0x8,
  0x0,0x47,0x5a,0xe7,
  0x0,0x66,
  0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/images
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/images/find.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_customsortfiltermodel)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_customsortfiltermodel)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_customsortfiltermodel)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_customsortfiltermodel)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_customsortfiltermodel)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_customsortfiltermodel)(); }
   } dummy;
}
